==> zio-aws-devopsguru_3-5.17.116.2-sources.jar: zio/aws/devopsguru/model/InsightTimeRange.scala <==
package zio.aws.devopsguru.model
import zio.aws.devopsguru.model.primitives.Timestamp
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import java.time.Instant
import scala.jdk.CollectionConverters.*
final case class InsightTimeRange(
    startTime: Timestamp,
    endTime: Option[Timestamp] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devopsguru.model.InsightTimeRange = {
    import InsightTimeRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devopsguru.model.InsightTimeRange
      .builder()
      .startTime(Timestamp.unwrap(startTime): Instant)
      .optionallyWith(endTime.map(value => Timestamp.unwrap(value): Instant))(
        _.endTime
      )
      .build()
  }
  def asReadOnly: zio.aws.devopsguru.model.InsightTimeRange.ReadOnly =
    zio.aws.devopsguru.model.InsightTimeRange.wrap(buildAwsValue())
}
object InsightTimeRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devopsguru.model.InsightTimeRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devopsguru.model.InsightTimeRange =
      zio.aws.devopsguru.model
        .InsightTimeRange(startTime, endTime.map(value => value))
    def startTime: Timestamp
    def endTime: Option[Timestamp]
    def getStartTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(startTime)
    def getEndTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("endTime", endTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devopsguru.model.InsightTimeRange
  ) extends zio.aws.devopsguru.model.InsightTimeRange.ReadOnly {
    override val startTime: Timestamp =
      zio.aws.devopsguru.model.primitives.Timestamp(impl.startTime())
    override val endTime: Option[Timestamp] = scala
      .Option(impl.endTime())
      .map(value => zio.aws.devopsguru.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devopsguru.model.InsightTimeRange
  ): zio.aws.devopsguru.model.InsightTimeRange.ReadOnly = new Wrapper(impl)
}

==> zio-aws-devopsguru_3-5.17.239.4-sources.jar: zio/aws/devopsguru/model/InsightTimeRange.scala <==
package zio.aws.devopsguru.model
import java.time.Instant
import zio.prelude.data.Optional
import zio.aws.core.{AwsError, BuilderHelper}
import zio.ZIO
import zio.aws.devopsguru.model.primitives.Timestamp
import scala.jdk.CollectionConverters.*
final case class InsightTimeRange(
    startTime: Timestamp,
    endTime: Optional[Timestamp] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.devopsguru.model.InsightTimeRange = {
    import InsightTimeRange.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.devopsguru.model.InsightTimeRange
      .builder()
      .startTime(Timestamp.unwrap(startTime): Instant)
      .optionallyWith(endTime.map(value => Timestamp.unwrap(value): Instant))(
        _.endTime
      )
      .build()
  }
  def asReadOnly: zio.aws.devopsguru.model.InsightTimeRange.ReadOnly =
    zio.aws.devopsguru.model.InsightTimeRange.wrap(buildAwsValue())
}
object InsightTimeRange {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.devopsguru.model.InsightTimeRange
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.devopsguru.model.InsightTimeRange =
      zio.aws.devopsguru.model
        .InsightTimeRange(startTime, endTime.map(value => value))
    def startTime: Timestamp
    def endTime: Optional[Timestamp]
    def getStartTime: ZIO[Any, Nothing, Timestamp] = ZIO.succeed(startTime)
    def getEndTime: ZIO[Any, AwsError, Timestamp] =
      AwsError.unwrapOptionField("endTime", endTime)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.devopsguru.model.InsightTimeRange
  ) extends zio.aws.devopsguru.model.InsightTimeRange.ReadOnly {
    override val startTime: Timestamp =
      zio.aws.devopsguru.model.primitives.Timestamp(impl.startTime())
    override val endTime: Optional[Timestamp] = zio.aws.core.internal
      .optionalFromNullable(impl.endTime())
      .map(value => zio.aws.devopsguru.model.primitives.Timestamp(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.devopsguru.model.InsightTimeRange
  ): zio.aws.devopsguru.model.InsightTimeRange.ReadOnly = new Wrapper(impl)
}
